(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs'), require('@angular/common'), require('@tensorflow-models/blazeface'), require('@tensorflow-models/mobilenet'), require('@tensorflow/tfjs')) :
    typeof define === 'function' && define.amd ? define('psm-face-captcha', ['exports', '@angular/core', 'rxjs', '@angular/common', '@tensorflow-models/blazeface', '@tensorflow-models/mobilenet', '@tensorflow/tfjs'], factory) :
    (global = global || self, factory(global['psm-face-captcha'] = {}, global.ng.core, global.rxjs, global.ng.common, global.blazeface, global.mobilenet, global.tf));
}(this, (function (exports, i0, rxjs, common, blazeface, mobilenet, tf) { 'use strict';

    var Error;
    (function (Error) {
        Error[Error["CONFIGURATION"] = -1] = "CONFIGURATION";
        Error[Error["CAMERA"] = -2] = "CAMERA";
        Error[Error["PREDICTION"] = -3] = "PREDICTION";
        Error[Error["BLAZE_FACE"] = -4] = "BLAZE_FACE";
        Error[Error["MOBILE_NET"] = -5] = "MOBILE_NET";
        Error[Error["IMAGE"] = -6] = "IMAGE";
        Error[Error["CHARGE"] = -7] = "CHARGE";
    })(Error || (Error = {}));

    var PsmErrorDescription = {
        CONFIGURATION: { code: Error.CONFIGURATION, error: 'La imágen de la compañía es requerida' },
        CAMERA: { code: Error.CAMERA, error: 'Error en la cámara' },
        TENSORFLOW_PREDICTION: { code: Error.PREDICTION, error: 'Error en la predicción de tensorflow' },
        BLAZE_FACE: { code: Error.BLAZE_FACE, error: 'Error al inicializar modelo blaceface' },
        MOBILE_NET: { code: Error.MOBILE_NET, error: 'Error al inicializar modelo MOBILNET' },
        IMAGE_ERROR: { code: Error.IMAGE, error: 'Error al cargar la imagen' },
        CHARGE: { code: Error.CHARGE, error: 'No se han cargado todos los elementos de tensorflow' },
    };

    var EventService = /** @class */ (function () {
        function EventService() {
            // loader
            this.counter = 0;
            this.loaderState = new rxjs.Subject();
            // error
            this.errorState = new rxjs.Subject();
            // data
            this.dataState = new rxjs.Subject();
        }
        // loader
        EventService.prototype.displayLoader = function (show) {
            show ? this.counter++ : this.counter--;
            this.loaderState.next(this.counter ? true : false);
        };
        Object.defineProperty(EventService.prototype, "verifyStateLoader", {
            get: function () {
                return this.loaderState.asObservable();
            },
            enumerable: false,
            configurable: true
        });
        // error
        EventService.prototype.displayError = function (error) {
            this.errorState.next(error);
        };
        Object.defineProperty(EventService.prototype, "verifyStateError", {
            get: function () {
                return this.errorState.asObservable();
            },
            enumerable: false,
            configurable: true
        });
        // data
        EventService.prototype.displayData = function (data) {
            this.dataState.next(data);
        };
        Object.defineProperty(EventService.prototype, "verifyStateData", {
            get: function () {
                return this.dataState.asObservable();
            },
            enumerable: false,
            configurable: true
        });
        return EventService;
    }());
    EventService.ɵprov = i0.ɵɵdefineInjectable({ factory: function EventService_Factory() { return new EventService(); }, token: EventService, providedIn: "root" });
    EventService.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    EventService.ctorParameters = function () { return []; };

    var PsmFaceCaptchaComponent = /** @class */ (function () {
        function PsmFaceCaptchaComponent(eventService) {
            this.eventService = eventService;
            this.backgroundIcon = 'white';
            this.switchCamera = true;
            this.onerror = new i0.EventEmitter();
            this.onloader = new i0.EventEmitter();
            this.ondata = new i0.EventEmitter();
            this.showCamera = true;
        }
        PsmFaceCaptchaComponent.prototype.ngOnInit = function () {
            this.getLoaderState();
            this.getErrorState();
            this.getDataState();
            this.validateInputData();
        };
        PsmFaceCaptchaComponent.prototype.validateInputData = function () {
            if (!this.companySrc) {
                this.showCamera = false;
                this.eventService.displayError(PsmErrorDescription.CONFIGURATION);
                return;
            }
        };
        PsmFaceCaptchaComponent.prototype.getLoaderState = function () {
            var _this = this;
            this.loaderService = this.eventService.verifyStateLoader.subscribe(function (res) {
                _this.onloader.emit(res);
            });
        };
        PsmFaceCaptchaComponent.prototype.getErrorState = function () {
            var _this = this;
            this.errorService = this.eventService.verifyStateError.subscribe(function (res) {
                _this.onerror.emit(res);
            });
        };
        PsmFaceCaptchaComponent.prototype.getDataState = function () {
            var _this = this;
            this.dataService = this.eventService.verifyStateData.subscribe(function (res) {
                _this.showCamera = false;
                _this.ondata.emit(res);
            });
        };
        PsmFaceCaptchaComponent.prototype.ngOnDestroy = function () {
            if (this.loaderService)
                this.loaderService.unsubscribe();
            if (this.errorService)
                this.errorService.unsubscribe();
            if (this.dataService)
                this.dataService.unsubscribe();
        };
        return PsmFaceCaptchaComponent;
    }());
    PsmFaceCaptchaComponent.decorators = [
        { type: i0.Component, args: [{
                    selector: 'lib-psm-face-captcha',
                    template: "<lib-camera *ngIf=\"showCamera\" [backgroundIcon]=\"backgroundIcon\" [companySrc]=\"companySrc\"></lib-camera>\r\n",
                    styles: [":host{box-sizing:border-box;display:block;height:100%;left:0;position:fixed;top:0;width:100%}"]
                },] }
    ];
    PsmFaceCaptchaComponent.ctorParameters = function () { return [
        { type: EventService }
    ]; };
    PsmFaceCaptchaComponent.propDecorators = {
        companySrc: [{ type: i0.Input }],
        backgroundIcon: [{ type: i0.Input }],
        switchCamera: [{ type: i0.Input }],
        onerror: [{ type: i0.Output }],
        onloader: [{ type: i0.Output }],
        ondata: [{ type: i0.Output }]
    };

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */
    /* global Reflect, Promise */
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b)
                if (Object.prototype.hasOwnProperty.call(b, p))
                    d[p] = b[p]; };
        return extendStatics(d, b);
    };
    function __extends(d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }
    var __assign = function () {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p))
                        t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };
    function __rest(s, e) {
        var t = {};
        for (var p in s)
            if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                    t[p[i]] = s[p[i]];
            }
        return t;
    }
    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
            r = Reflect.decorate(decorators, target, key, desc);
        else
            for (var i = decorators.length - 1; i >= 0; i--)
                if (d = decorators[i])
                    r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }
    function __param(paramIndex, decorator) {
        return function (target, key) { decorator(target, key, paramIndex); };
    }
    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
            return Reflect.metadata(metadataKey, metadataValue);
    }
    function __awaiter(thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try {
                step(generator.next(value));
            }
            catch (e) {
                reject(e);
            } }
            function rejected(value) { try {
                step(generator["throw"](value));
            }
            catch (e) {
                reject(e);
            } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    }
    function __generator(thisArg, body) {
        var _ = { label: 0, sent: function () { if (t[0] & 1)
                throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function () { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f)
                throw new TypeError("Generator is already executing.");
            while (_)
                try {
                    if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done)
                        return t;
                    if (y = 0, t)
                        op = [op[0] & 2, t.value];
                    switch (op[0]) {
                        case 0:
                        case 1:
                            t = op;
                            break;
                        case 4:
                            _.label++;
                            return { value: op[1], done: false };
                        case 5:
                            _.label++;
                            y = op[1];
                            op = [0];
                            continue;
                        case 7:
                            op = _.ops.pop();
                            _.trys.pop();
                            continue;
                        default:
                            if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                                _ = 0;
                                continue;
                            }
                            if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) {
                                _.label = op[1];
                                break;
                            }
                            if (op[0] === 6 && _.label < t[1]) {
                                _.label = t[1];
                                t = op;
                                break;
                            }
                            if (t && _.label < t[2]) {
                                _.label = t[2];
                                _.ops.push(op);
                                break;
                            }
                            if (t[2])
                                _.ops.pop();
                            _.trys.pop();
                            continue;
                    }
                    op = body.call(thisArg, _);
                }
                catch (e) {
                    op = [6, e];
                    y = 0;
                }
                finally {
                    f = t = 0;
                }
            if (op[0] & 5)
                throw op[1];
            return { value: op[0] ? op[1] : void 0, done: true };
        }
    }
    var __createBinding = Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        Object.defineProperty(o, k2, { enumerable: true, get: function () { return m[k]; } });
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    });
    function __exportStar(m, o) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p))
                __createBinding(o, m, p);
    }
    function __values(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m)
            return m.call(o);
        if (o && typeof o.length === "number")
            return {
                next: function () {
                    if (o && i >= o.length)
                        o = void 0;
                    return { value: o && o[i++], done: !o };
                }
            };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    }
    function __read(o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m)
            return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
                ar.push(r.value);
        }
        catch (error) {
            e = { error: error };
        }
        finally {
            try {
                if (r && !r.done && (m = i["return"]))
                    m.call(i);
            }
            finally {
                if (e)
                    throw e.error;
            }
        }
        return ar;
    }
    /** @deprecated */
    function __spread() {
        for (var ar = [], i = 0; i < arguments.length; i++)
            ar = ar.concat(__read(arguments[i]));
        return ar;
    }
    /** @deprecated */
    function __spreadArrays() {
        for (var s = 0, i = 0, il = arguments.length; i < il; i++)
            s += arguments[i].length;
        for (var r = Array(s), k = 0, i = 0; i < il; i++)
            for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
                r[k] = a[j];
        return r;
    }
    function __spreadArray(to, from) {
        for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
            to[j] = from[i];
        return to;
    }
    function __await(v) {
        return this instanceof __await ? (this.v = v, this) : new __await(v);
    }
    function __asyncGenerator(thisArg, _arguments, generator) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var g = generator.apply(thisArg, _arguments || []), i, q = [];
        return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
        function verb(n) { if (g[n])
            i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
        function resume(n, v) { try {
            step(g[n](v));
        }
        catch (e) {
            settle(q[0][3], e);
        } }
        function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
        function fulfill(value) { resume("next", value); }
        function reject(value) { resume("throw", value); }
        function settle(f, v) { if (f(v), q.shift(), q.length)
            resume(q[0][0], q[0][1]); }
    }
    function __asyncDelegator(o) {
        var i, p;
        return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
        function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }
    }
    function __asyncValues(o) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var m = o[Symbol.asyncIterator], i;
        return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
        function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
        function settle(resolve, reject, d, v) { Promise.resolve(v).then(function (v) { resolve({ value: v, done: d }); }, reject); }
    }
    function __makeTemplateObject(cooked, raw) {
        if (Object.defineProperty) {
            Object.defineProperty(cooked, "raw", { value: raw });
        }
        else {
            cooked.raw = raw;
        }
        return cooked;
    }
    ;
    var __setModuleDefault = Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    };
    function __importStar(mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    }
    function __importDefault(mod) {
        return (mod && mod.__esModule) ? mod : { default: mod };
    }
    function __classPrivateFieldGet(receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    }
    function __classPrivateFieldSet(receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    }

    var Image;
    (function (Image) {
        Image[Image["WIDTH"] = 640] = "WIDTH";
        Image[Image["HEIGHT"] = 480] = "HEIGHT";
    })(Image || (Image = {}));

    var TensorflowService = /** @class */ (function () {
        function TensorflowService(eventService) {
            this.eventService = eventService;
            tf.getBackend();
            this.loadBlazeFace();
            this.loadMobilenet();
        }
        TensorflowService.prototype.loadBlazeFace = function () {
            return __awaiter(this, void 0, void 0, function () {
                var _a;
                return __generator(this, function (_b) {
                    switch (_b.label) {
                        case 0:
                            this.eventService.displayLoader(true);
                            _a = this;
                            return [4 /*yield*/, blazeface.load().then(function (res) { return res; }).catch(function () { return null; })];
                        case 1:
                            _a.blazefaceModel = _b.sent();
                            if (!this.blazefaceModel)
                                this.eventService.displayError(PsmErrorDescription.TENSORFLOW_PREDICTION);
                            this.eventService.displayLoader(false);
                            return [2 /*return*/];
                    }
                });
            });
        };
        TensorflowService.prototype.loadMobilenet = function () {
            return __awaiter(this, void 0, void 0, function () {
                var _a;
                return __generator(this, function (_b) {
                    switch (_b.label) {
                        case 0:
                            this.eventService.displayLoader(true);
                            _a = this;
                            return [4 /*yield*/, mobilenet.load().then(function (res) { return res; }).catch(function () { return null; })];
                        case 1:
                            _a.mobilenetModel = _b.sent();
                            if (!this.mobilenetModel)
                                this.eventService.displayError(PsmErrorDescription.MOBILE_NET);
                            this.eventService.displayLoader(false);
                            return [2 /*return*/];
                    }
                });
            });
        };
        TensorflowService.prototype.getPrediction = function (element) {
            return __awaiter(this, void 0, void 0, function () {
                var face, data, error_1;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            this.eventService.displayLoader(true);
                            _a.label = 1;
                        case 1:
                            _a.trys.push([1, 4, , 5]);
                            return [4 /*yield*/, this.blazefaceModel.estimateFaces(element, false)];
                        case 2:
                            face = _a.sent();
                            return [4 /*yield*/, this.mobilenetModel.classify(element)];
                        case 3:
                            data = _a.sent();
                            this.eventService.displayLoader(false);
                            return [2 /*return*/, {
                                    hasFace: face && face.length > 0 ? true : false,
                                    facesDetected: face.length,
                                    objectPrediction: data,
                                    image: null
                                }];
                        case 4:
                            error_1 = _a.sent();
                            this.eventService.displayLoader(false);
                            return [2 /*return*/, null];
                        case 5: return [2 /*return*/];
                    }
                });
            });
        };
        TensorflowService.prototype.getPredictionData = function (src) {
            return __awaiter(this, void 0, void 0, function () {
                var img, data;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            if (!this.blazefaceModel || !this.mobilenetModel) {
                                this.eventService.displayError(PsmErrorDescription.CHARGE);
                                return [2 /*return*/];
                            }
                            return [4 /*yield*/, this.getImage(src).then(function (res) { return res; })];
                        case 1:
                            img = _a.sent();
                            if (!img) return [3 /*break*/, 3];
                            return [4 /*yield*/, this.getPrediction(img)];
                        case 2:
                            data = _a.sent();
                            if (data)
                                this.eventService.displayData(data);
                            else
                                this.eventService.displayError(PsmErrorDescription.TENSORFLOW_PREDICTION);
                            return [3 /*break*/, 4];
                        case 3:
                            this.eventService.displayError(PsmErrorDescription.IMAGE_ERROR);
                            _a.label = 4;
                        case 4: return [2 /*return*/];
                    }
                });
            });
        };
        TensorflowService.prototype.getImage = function (src) {
            return new Promise(function (resolve, reject) {
                var img = document.createElement('img');
                img.id = 'psm-img';
                img.src = src;
                img.onload = function () {
                    console.log('leído');
                    resolve(img);
                };
                img.onerror = function () {
                    resolve(null);
                };
            });
        };
        return TensorflowService;
    }());
    TensorflowService.ɵprov = i0.ɵɵdefineInjectable({ factory: function TensorflowService_Factory() { return new TensorflowService(i0.ɵɵinject(EventService)); }, token: TensorflowService, providedIn: "root" });
    TensorflowService.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    TensorflowService.ctorParameters = function () { return [
        { type: EventService }
    ]; };

    var CameraComponent = /** @class */ (function () {
        function CameraComponent(eventService, tensorflowService) {
            this.eventService = eventService;
            this.tensorflowService = tensorflowService;
            this.constraints = {
                video: {
                    width: Image.WIDTH,
                    height: Image.HEIGHT,
                    facingMode: 'user'
                },
                audio: false
            };
        }
        CameraComponent.prototype.ngAfterViewInit = function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            this.eventService.displayLoader(true);
                            return [4 /*yield*/, this.getUserMedia(this.constraints)];
                        case 1:
                            _a.sent();
                            this.eventService.displayLoader(false);
                            return [2 /*return*/];
                    }
                });
            });
        };
        CameraComponent.prototype.takepicture = function () {
            return __awaiter(this, void 0, void 0, function () {
                var photo, prediction;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            this.canvas.nativeElement.getContext("2d").drawImage(this.video.nativeElement, 0, 0, 640, 480);
                            photo = this.canvas.nativeElement.toDataURL("image/png");
                            this.video.nativeElement.pause();
                            this.video.nativeElement.srcObject = null;
                            this.stream.getTracks().forEach(function (track) { return track.stop(); });
                            return [4 /*yield*/, this.tensorflowService.getPrediction(this.canvas.nativeElement)];
                        case 1:
                            prediction = _a.sent();
                            if (prediction) {
                                prediction.image = photo;
                                this.eventService.displayData(prediction);
                            }
                            else
                                this.eventService.displayError(PsmErrorDescription.TENSORFLOW_PREDICTION);
                            return [2 /*return*/];
                    }
                });
            });
        };
        CameraComponent.prototype.switchCamera = function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            if (this.constraints.video.facingMode === 'user')
                                this.constraints.video.facingMode = 'environment';
                            else
                                this.constraints.video.facingMode = 'user';
                            return [4 /*yield*/, this.getUserMedia(this.constraints)];
                        case 1:
                            _a.sent();
                            return [2 /*return*/];
                    }
                });
            });
        };
        CameraComponent.prototype.getUserMedia = function (constraints) {
            return __awaiter(this, void 0, void 0, function () {
                var stream;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            if (this.stream) {
                                this.video.nativeElement.pause();
                                this.video.nativeElement.srcObject = null;
                                this.stream.getTracks().forEach(function (track) { return track.stop(); });
                            }
                            return [4 /*yield*/, navigator.mediaDevices.getUserMedia(constraints).then(function (stream) { return stream; }).catch(function () { return null; })];
                        case 1:
                            stream = _a.sent();
                            if (stream) {
                                this.stream = stream;
                                this.video.nativeElement.srcObject = stream;
                                this.video.nativeElement.play();
                            }
                            else
                                this.eventService.displayError(PsmErrorDescription.CAMERA);
                            return [2 /*return*/];
                    }
                });
            });
        };
        CameraComponent.prototype.ngOnDestroy = function () {
            if (this.stream)
                this.stream.getTracks().forEach(function (track) { return track.stop(); });
        };
        return CameraComponent;
    }());
    CameraComponent.decorators = [
        { type: i0.Component, args: [{
                    selector: 'lib-camera',
                    template: "\r\n<video #video playsinline [muted]=\"'muted'\" [width]=\"constraints.video.width\" [height]=\"constraints.video.height\"></video>\r\n<div class=\"container-company\"><img [src]=\"companySrc\" alt=\"company\"></div>\r\n<lib-capture [backgroundIcon]=\"backgroundIcon\" (click)=\"takepicture()\"></lib-capture>\r\n<lib-switch [backgroundIcon]=\"backgroundIcon\" (click)=\"switchCamera()\"></lib-switch>\r\n<canvas #canvas [width]=\"constraints.video.width\" [height]=\"constraints.video.height\"></canvas>\r\n",
                    styles: [":host,:host video{display:block;height:100%;width:100%}:host video{object-fit:cover}:host canvas{display:none}:host .container-company{max-height:100px;max-width:100px;position:fixed;right:3%;top:3%}:host .container-company img{max-height:100%;max-width:100%}"]
                },] }
    ];
    CameraComponent.ctorParameters = function () { return [
        { type: EventService },
        { type: TensorflowService }
    ]; };
    CameraComponent.propDecorators = {
        backgroundIcon: [{ type: i0.Input }],
        companySrc: [{ type: i0.Input }],
        video: [{ type: i0.ViewChild, args: ["video",] }],
        canvas: [{ type: i0.ViewChild, args: ["canvas",] }]
    };

    var CaptureComponent = /** @class */ (function () {
        function CaptureComponent() {
        }
        return CaptureComponent;
    }());
    CaptureComponent.decorators = [
        { type: i0.Component, args: [{
                    selector: 'lib-capture',
                    template: "<svg xmlns=\"http://www.w3.org/2000/svg\" data-name=\"PSM CAPTURE\" viewBox=\"0 0 100 100\" x=\"0px\" y=\"0px\">\r\n  <title>PSM CAPTURE</title>\r\n  <path [attr.fill]=\"backgroundIcon\" d=\"M48,58A10,10,0,1,0,38,48,10,10,0,0,0,48,58Zm0-14a4,4,0,1,1-4,4A4,4,0,0,1,48,44Z\" />\r\n  <path [attr.fill]=\"backgroundIcon\" d=\"M75,39V28a7,7,0,0,0-7-7H57v6H68a1,1,0,0,1,1,1V39Z\" />\r\n  <path [attr.fill]=\"backgroundIcon\" d=\"M21,28V39h6V28a1,1,0,0,1,1-1H39V21H28A7,7,0,0,0,21,28Z\" />\r\n  <path [attr.fill]=\"backgroundIcon\" d=\"M21,68a7,7,0,0,0,7,7H39V69H28a1,1,0,0,1-1-1V57H21Z\" />\r\n  <circle [attr.fill]=\"backgroundIcon\" cx=\"65.5\" cy=\"65.5\" r=\"3.5\" />\r\n</svg>\r\n",
                    styles: [":host{bottom:0;left:50%;position:fixed;transform:translate(-50%);width:100px;z-index:2}"]
                },] }
    ];
    CaptureComponent.propDecorators = {
        backgroundIcon: [{ type: i0.Input }]
    };

    var SwitchComponent = /** @class */ (function () {
        function SwitchComponent() {
        }
        return SwitchComponent;
    }());
    SwitchComponent.decorators = [
        { type: i0.Component, args: [{
                    selector: 'lib-switch',
                    template: "<svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" version=\"1.1\" x=\"0px\" y=\"0px\"\r\n  viewBox=\"0 0 100 100\" enable-background=\"new 0 0 100 100\" xml:space=\"preserve\">\r\n  <path\r\n    [attr.fill]=\"backgroundIcon\"\r\n    d=\"M60.535,22.332c1.611,0,3.116,0.808,4.011,2.147l4.368,6.956c0.896,1.342,2.399,2.146,4.014,2.146h14.294  c2.664,0,4.822,2.16,4.822,4.822v40.178c0,2.664-2.158,4.822-4.822,4.822H13.294c-2.662,0-4.822-2.158-4.822-4.822V38.404  c0-2.662,2.16-4.822,4.822-4.822h14.294c1.612,0,3.117-0.805,4.012-2.146l4.37-6.956c0.895-1.34,2.397-2.147,4.011-2.147H60.535   M60.535,19.118H39.98c-2.692,0-5.191,1.339-6.686,3.578l-4.369,6.956c-0.299,0.447-0.799,0.716-1.338,0.716H13.294  c-4.431,0-8.036,3.605-8.036,8.036v40.178c0,4.433,3.605,8.036,8.036,8.036h73.928c4.433,0,8.036-3.604,8.036-8.036V38.404  c0-4.431-3.604-8.036-8.036-8.036H72.928c-0.539,0-1.039-0.269-1.338-0.716l-4.369-6.956C65.727,20.457,63.228,19.118,60.535,19.118  \" />\r\n  <path\r\n    [attr.fill]=\"backgroundIcon\"\r\n    d=\"M71.109,54.476c-0.425-10.72-9.225-19.286-20.048-19.286c-5.258,0-10.029,2.037-13.61,5.344l3.415,3.414  c2.706-2.438,6.274-3.937,10.195-3.937c8.148,0,14.805,6.421,15.227,14.465h-5.584L68.74,64.52l8.035-10.044H71.109z\" />\r\n  <path\r\n    [attr.fill]=\"backgroundIcon\"\r\n    d=\"M51.062,70.547c-8.011,0-14.566-6.209-15.187-14.062h5.544l-8.036-10.045l-8.036,10.045h5.702  c0.626,10.528,9.326,18.884,20.013,18.884c5.258,0,10.028-2.035,13.61-5.343l-3.415-3.415C58.551,69.05,54.982,70.547,51.062,70.547  \" />\r\n</svg>\r\n",
                    styles: [":host{bottom:3%;position:fixed;right:5%;width:60px;z-index:2}"]
                },] }
    ];
    SwitchComponent.propDecorators = {
        backgroundIcon: [{ type: i0.Input }]
    };

    var PsmFaceCaptchaModule = /** @class */ (function () {
        function PsmFaceCaptchaModule() {
        }
        return PsmFaceCaptchaModule;
    }());
    PsmFaceCaptchaModule.decorators = [
        { type: i0.NgModule, args: [{
                    declarations: [
                        PsmFaceCaptchaComponent,
                        CameraComponent,
                        CaptureComponent,
                        SwitchComponent
                    ],
                    imports: [
                        common.CommonModule
                    ],
                    exports: [PsmFaceCaptchaComponent]
                },] }
    ];

    var PsmCaptchaService = /** @class */ (function () {
        function PsmCaptchaService(eventService, tensorflowService) {
            this.eventService = eventService;
            this.tensorflowService = tensorflowService;
        }
        PsmCaptchaService.prototype.getEvents = function () {
            return {
                loader: this.eventService.verifyStateLoader,
                error: this.eventService.verifyStateError,
                data: this.eventService.verifyStateData,
            };
        };
        PsmCaptchaService.prototype.getPrediction = function (src) {
            this.tensorflowService.getPredictionData(src);
        };
        return PsmCaptchaService;
    }());
    PsmCaptchaService.ɵprov = i0.ɵɵdefineInjectable({ factory: function PsmCaptchaService_Factory() { return new PsmCaptchaService(i0.ɵɵinject(EventService), i0.ɵɵinject(TensorflowService)); }, token: PsmCaptchaService, providedIn: "root" });
    PsmCaptchaService.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    PsmCaptchaService.ctorParameters = function () { return [
        { type: EventService },
        { type: TensorflowService }
    ]; };

    /*
     * Public API Surface of psm-face-captcha
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.PsmCaptchaService = PsmCaptchaService;
    exports.PsmFaceCaptchaComponent = PsmFaceCaptchaComponent;
    exports.PsmFaceCaptchaModule = PsmFaceCaptchaModule;
    exports.ɵa = EventService;
    exports.ɵb = CameraComponent;
    exports.ɵc = TensorflowService;
    exports.ɵd = CaptureComponent;
    exports.ɵe = SwitchComponent;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=psm-face-captcha.umd.js.map
