import { ɵɵdefineInjectable, Injectable, EventEmitter, Component, Input, Output, ɵɵinject, ViewChild, NgModule } from '@angular/core';
import { Subject } from 'rxjs';
import { CommonModule } from '@angular/common';
import { __awaiter } from 'tslib';
import { load } from '@tensorflow-models/blazeface';
import { load as load$1 } from '@tensorflow-models/mobilenet';
import { getBackend } from '@tensorflow/tfjs';

var Error;
(function (Error) {
    Error[Error["CONFIGURATION"] = -1] = "CONFIGURATION";
    Error[Error["CAMERA"] = -2] = "CAMERA";
    Error[Error["PREDICTION"] = -3] = "PREDICTION";
    Error[Error["BLAZE_FACE"] = -4] = "BLAZE_FACE";
    Error[Error["MOBILE_NET"] = -5] = "MOBILE_NET";
    Error[Error["IMAGE"] = -6] = "IMAGE";
    Error[Error["CHARGE"] = -7] = "CHARGE";
})(Error || (Error = {}));

const PsmErrorDescription = {
    CONFIGURATION: { code: Error.CONFIGURATION, error: 'La imágen de la compañía es requerida' },
    CAMERA: { code: Error.CAMERA, error: 'Error en la cámara' },
    TENSORFLOW_PREDICTION: { code: Error.PREDICTION, error: 'Error en la predicción de tensorflow' },
    BLAZE_FACE: { code: Error.BLAZE_FACE, error: 'Error al inicializar modelo blaceface' },
    MOBILE_NET: { code: Error.MOBILE_NET, error: 'Error al inicializar modelo MOBILNET' },
    IMAGE_ERROR: { code: Error.IMAGE, error: 'Error al cargar la imagen' },
    CHARGE: { code: Error.CHARGE, error: 'No se han cargado todos los elementos de tensorflow' },
};

class EventService {
    constructor() {
        // loader
        this.counter = 0;
        this.loaderState = new Subject();
        // error
        this.errorState = new Subject();
        // data
        this.dataState = new Subject();
    }
    // loader
    displayLoader(show) {
        show ? this.counter++ : this.counter--;
        this.loaderState.next(this.counter ? true : false);
    }
    get verifyStateLoader() {
        return this.loaderState.asObservable();
    }
    // error
    displayError(error) {
        this.errorState.next(error);
    }
    get verifyStateError() {
        return this.errorState.asObservable();
    }
    // data
    displayData(data) {
        this.dataState.next(data);
    }
    get verifyStateData() {
        return this.dataState.asObservable();
    }
}
EventService.ɵprov = ɵɵdefineInjectable({ factory: function EventService_Factory() { return new EventService(); }, token: EventService, providedIn: "root" });
EventService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
EventService.ctorParameters = () => [];

class PsmFaceCaptchaComponent {
    constructor(eventService) {
        this.eventService = eventService;
        this.backgroundIcon = 'white';
        this.switchCamera = true;
        this.onerror = new EventEmitter();
        this.onloader = new EventEmitter();
        this.ondata = new EventEmitter();
        this.showCamera = true;
    }
    ngOnInit() {
        this.getLoaderState();
        this.getErrorState();
        this.getDataState();
        this.validateInputData();
    }
    validateInputData() {
        if (!this.companySrc) {
            this.showCamera = false;
            this.eventService.displayError(PsmErrorDescription.CONFIGURATION);
            return;
        }
    }
    getLoaderState() {
        this.loaderService = this.eventService.verifyStateLoader.subscribe(res => {
            this.onloader.emit(res);
        });
    }
    getErrorState() {
        this.errorService = this.eventService.verifyStateError.subscribe(res => {
            this.onerror.emit(res);
        });
    }
    getDataState() {
        this.dataService = this.eventService.verifyStateData.subscribe(res => {
            this.showCamera = false;
            this.ondata.emit(res);
        });
    }
    ngOnDestroy() {
        if (this.loaderService)
            this.loaderService.unsubscribe();
        if (this.errorService)
            this.errorService.unsubscribe();
        if (this.dataService)
            this.dataService.unsubscribe();
    }
}
PsmFaceCaptchaComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-psm-face-captcha',
                template: "<lib-camera *ngIf=\"showCamera\" [backgroundIcon]=\"backgroundIcon\" [companySrc]=\"companySrc\"></lib-camera>\r\n",
                styles: [":host{box-sizing:border-box;display:block;height:100%;left:0;position:fixed;top:0;width:100%}"]
            },] }
];
PsmFaceCaptchaComponent.ctorParameters = () => [
    { type: EventService }
];
PsmFaceCaptchaComponent.propDecorators = {
    companySrc: [{ type: Input }],
    backgroundIcon: [{ type: Input }],
    switchCamera: [{ type: Input }],
    onerror: [{ type: Output }],
    onloader: [{ type: Output }],
    ondata: [{ type: Output }]
};

var Image;
(function (Image) {
    Image[Image["WIDTH"] = 640] = "WIDTH";
    Image[Image["HEIGHT"] = 480] = "HEIGHT";
})(Image || (Image = {}));

class TensorflowService {
    constructor(eventService) {
        this.eventService = eventService;
        getBackend();
        this.loadBlazeFace();
        this.loadMobilenet();
    }
    loadBlazeFace() {
        return __awaiter(this, void 0, void 0, function* () {
            this.eventService.displayLoader(true);
            this.blazefaceModel = yield load().then(res => res).catch(() => null);
            if (!this.blazefaceModel)
                this.eventService.displayError(PsmErrorDescription.TENSORFLOW_PREDICTION);
            this.eventService.displayLoader(false);
        });
    }
    loadMobilenet() {
        return __awaiter(this, void 0, void 0, function* () {
            this.eventService.displayLoader(true);
            this.mobilenetModel = yield load$1().then(res => res).catch(() => null);
            if (!this.mobilenetModel)
                this.eventService.displayError(PsmErrorDescription.MOBILE_NET);
            this.eventService.displayLoader(false);
        });
    }
    getPrediction(element) {
        return __awaiter(this, void 0, void 0, function* () {
            this.eventService.displayLoader(true);
            try {
                const face = yield this.blazefaceModel.estimateFaces(element, false);
                const data = yield this.mobilenetModel.classify(element);
                this.eventService.displayLoader(false);
                return {
                    hasFace: face && face.length > 0 ? true : false,
                    facesDetected: face.length,
                    objectPrediction: data,
                    image: null
                };
            }
            catch (error) {
                this.eventService.displayLoader(false);
                return null;
            }
        });
    }
    getPredictionData(src) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.blazefaceModel || !this.mobilenetModel) {
                this.eventService.displayError(PsmErrorDescription.CHARGE);
                return;
            }
            const img = yield this.getImage(src).then(res => res);
            if (img) {
                const data = yield this.getPrediction(img);
                if (data)
                    this.eventService.displayData(data);
                else
                    this.eventService.displayError(PsmErrorDescription.TENSORFLOW_PREDICTION);
            }
            else
                this.eventService.displayError(PsmErrorDescription.IMAGE_ERROR);
        });
    }
    getImage(src) {
        return new Promise((resolve, reject) => {
            const img = document.createElement('img');
            img.id = 'psm-img';
            img.src = src;
            img.onload = () => {
                console.log('leído');
                resolve(img);
            };
            img.onerror = () => {
                resolve(null);
            };
        });
    }
}
TensorflowService.ɵprov = ɵɵdefineInjectable({ factory: function TensorflowService_Factory() { return new TensorflowService(ɵɵinject(EventService)); }, token: TensorflowService, providedIn: "root" });
TensorflowService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
TensorflowService.ctorParameters = () => [
    { type: EventService }
];

class CameraComponent {
    constructor(eventService, tensorflowService) {
        this.eventService = eventService;
        this.tensorflowService = tensorflowService;
        this.constraints = {
            video: {
                width: Image.WIDTH,
                height: Image.HEIGHT,
                facingMode: 'user'
            },
            audio: false
        };
    }
    ngAfterViewInit() {
        return __awaiter(this, void 0, void 0, function* () {
            this.eventService.displayLoader(true);
            yield this.getUserMedia(this.constraints);
            this.eventService.displayLoader(false);
        });
    }
    takepicture() {
        return __awaiter(this, void 0, void 0, function* () {
            this.canvas.nativeElement.getContext("2d").drawImage(this.video.nativeElement, 0, 0, 640, 480);
            const photo = this.canvas.nativeElement.toDataURL("image/png");
            this.video.nativeElement.pause();
            this.video.nativeElement.srcObject = null;
            this.stream.getTracks().forEach(track => track.stop());
            const prediction = yield this.tensorflowService.getPrediction(this.canvas.nativeElement);
            if (prediction) {
                prediction.image = photo;
                this.eventService.displayData(prediction);
            }
            else
                this.eventService.displayError(PsmErrorDescription.TENSORFLOW_PREDICTION);
        });
    }
    switchCamera() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.constraints.video.facingMode === 'user')
                this.constraints.video.facingMode = 'environment';
            else
                this.constraints.video.facingMode = 'user';
            yield this.getUserMedia(this.constraints);
        });
    }
    getUserMedia(constraints) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.stream) {
                this.video.nativeElement.pause();
                this.video.nativeElement.srcObject = null;
                this.stream.getTracks().forEach(track => track.stop());
            }
            const stream = yield navigator.mediaDevices.getUserMedia(constraints).then((stream) => stream).catch(() => null);
            if (stream) {
                this.stream = stream;
                this.video.nativeElement.srcObject = stream;
                this.video.nativeElement.play();
            }
            else
                this.eventService.displayError(PsmErrorDescription.CAMERA);
        });
    }
    ngOnDestroy() {
        if (this.stream)
            this.stream.getTracks().forEach(track => track.stop());
    }
}
CameraComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-camera',
                template: "\r\n<video #video playsinline [muted]=\"'muted'\" [width]=\"constraints.video.width\" [height]=\"constraints.video.height\"></video>\r\n<div class=\"container-company\"><img [src]=\"companySrc\" alt=\"company\"></div>\r\n<lib-capture [backgroundIcon]=\"backgroundIcon\" (click)=\"takepicture()\"></lib-capture>\r\n<lib-switch [backgroundIcon]=\"backgroundIcon\" (click)=\"switchCamera()\"></lib-switch>\r\n<canvas #canvas [width]=\"constraints.video.width\" [height]=\"constraints.video.height\"></canvas>\r\n",
                styles: [":host,:host video{display:block;height:100%;width:100%}:host video{object-fit:cover}:host canvas{display:none}:host .container-company{max-height:100px;max-width:100px;position:fixed;right:3%;top:3%}:host .container-company img{max-height:100%;max-width:100%}"]
            },] }
];
CameraComponent.ctorParameters = () => [
    { type: EventService },
    { type: TensorflowService }
];
CameraComponent.propDecorators = {
    backgroundIcon: [{ type: Input }],
    companySrc: [{ type: Input }],
    video: [{ type: ViewChild, args: ["video",] }],
    canvas: [{ type: ViewChild, args: ["canvas",] }]
};

class CaptureComponent {
}
CaptureComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-capture',
                template: "<svg xmlns=\"http://www.w3.org/2000/svg\" data-name=\"PSM CAPTURE\" viewBox=\"0 0 100 100\" x=\"0px\" y=\"0px\">\r\n  <title>PSM CAPTURE</title>\r\n  <path [attr.fill]=\"backgroundIcon\" d=\"M48,58A10,10,0,1,0,38,48,10,10,0,0,0,48,58Zm0-14a4,4,0,1,1-4,4A4,4,0,0,1,48,44Z\" />\r\n  <path [attr.fill]=\"backgroundIcon\" d=\"M75,39V28a7,7,0,0,0-7-7H57v6H68a1,1,0,0,1,1,1V39Z\" />\r\n  <path [attr.fill]=\"backgroundIcon\" d=\"M21,28V39h6V28a1,1,0,0,1,1-1H39V21H28A7,7,0,0,0,21,28Z\" />\r\n  <path [attr.fill]=\"backgroundIcon\" d=\"M21,68a7,7,0,0,0,7,7H39V69H28a1,1,0,0,1-1-1V57H21Z\" />\r\n  <circle [attr.fill]=\"backgroundIcon\" cx=\"65.5\" cy=\"65.5\" r=\"3.5\" />\r\n</svg>\r\n",
                styles: [":host{bottom:0;left:50%;position:fixed;transform:translate(-50%);width:100px;z-index:2}"]
            },] }
];
CaptureComponent.propDecorators = {
    backgroundIcon: [{ type: Input }]
};

class SwitchComponent {
}
SwitchComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-switch',
                template: "<svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" version=\"1.1\" x=\"0px\" y=\"0px\"\r\n  viewBox=\"0 0 100 100\" enable-background=\"new 0 0 100 100\" xml:space=\"preserve\">\r\n  <path\r\n    [attr.fill]=\"backgroundIcon\"\r\n    d=\"M60.535,22.332c1.611,0,3.116,0.808,4.011,2.147l4.368,6.956c0.896,1.342,2.399,2.146,4.014,2.146h14.294  c2.664,0,4.822,2.16,4.822,4.822v40.178c0,2.664-2.158,4.822-4.822,4.822H13.294c-2.662,0-4.822-2.158-4.822-4.822V38.404  c0-2.662,2.16-4.822,4.822-4.822h14.294c1.612,0,3.117-0.805,4.012-2.146l4.37-6.956c0.895-1.34,2.397-2.147,4.011-2.147H60.535   M60.535,19.118H39.98c-2.692,0-5.191,1.339-6.686,3.578l-4.369,6.956c-0.299,0.447-0.799,0.716-1.338,0.716H13.294  c-4.431,0-8.036,3.605-8.036,8.036v40.178c0,4.433,3.605,8.036,8.036,8.036h73.928c4.433,0,8.036-3.604,8.036-8.036V38.404  c0-4.431-3.604-8.036-8.036-8.036H72.928c-0.539,0-1.039-0.269-1.338-0.716l-4.369-6.956C65.727,20.457,63.228,19.118,60.535,19.118  \" />\r\n  <path\r\n    [attr.fill]=\"backgroundIcon\"\r\n    d=\"M71.109,54.476c-0.425-10.72-9.225-19.286-20.048-19.286c-5.258,0-10.029,2.037-13.61,5.344l3.415,3.414  c2.706-2.438,6.274-3.937,10.195-3.937c8.148,0,14.805,6.421,15.227,14.465h-5.584L68.74,64.52l8.035-10.044H71.109z\" />\r\n  <path\r\n    [attr.fill]=\"backgroundIcon\"\r\n    d=\"M51.062,70.547c-8.011,0-14.566-6.209-15.187-14.062h5.544l-8.036-10.045l-8.036,10.045h5.702  c0.626,10.528,9.326,18.884,20.013,18.884c5.258,0,10.028-2.035,13.61-5.343l-3.415-3.415C58.551,69.05,54.982,70.547,51.062,70.547  \" />\r\n</svg>\r\n",
                styles: [":host{bottom:3%;position:fixed;right:5%;width:60px;z-index:2}"]
            },] }
];
SwitchComponent.propDecorators = {
    backgroundIcon: [{ type: Input }]
};

class PsmFaceCaptchaModule {
}
PsmFaceCaptchaModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    PsmFaceCaptchaComponent,
                    CameraComponent,
                    CaptureComponent,
                    SwitchComponent
                ],
                imports: [
                    CommonModule
                ],
                exports: [PsmFaceCaptchaComponent]
            },] }
];

class PsmCaptchaService {
    constructor(eventService, tensorflowService) {
        this.eventService = eventService;
        this.tensorflowService = tensorflowService;
    }
    getEvents() {
        return {
            loader: this.eventService.verifyStateLoader,
            error: this.eventService.verifyStateError,
            data: this.eventService.verifyStateData,
        };
    }
    getPrediction(src) {
        this.tensorflowService.getPredictionData(src);
    }
}
PsmCaptchaService.ɵprov = ɵɵdefineInjectable({ factory: function PsmCaptchaService_Factory() { return new PsmCaptchaService(ɵɵinject(EventService), ɵɵinject(TensorflowService)); }, token: PsmCaptchaService, providedIn: "root" });
PsmCaptchaService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
PsmCaptchaService.ctorParameters = () => [
    { type: EventService },
    { type: TensorflowService }
];

/*
 * Public API Surface of psm-face-captcha
 */

/**
 * Generated bundle index. Do not edit.
 */

export { PsmCaptchaService, PsmFaceCaptchaComponent, PsmFaceCaptchaModule, EventService as ɵa, CameraComponent as ɵb, TensorflowService as ɵc, CaptureComponent as ɵd, SwitchComponent as ɵe };
//# sourceMappingURL=psm-face-captcha.js.map
